from os import getenv
import subprocess

from kombu import Queue, Exchange
from socket import gethostname
from celery import Celery


HOSTNAME = gethostname()
AMQP_URI = getenv('AMQP_URI')
CACHE_URI = getenv('CACHE_URI')

celery = Celery('dnsdriver', broker=AMQP_URI)
celery.conf.update(
    CELERY_RESULT_BACKEND='cache',
    CELERY_CACHE_BACKEND=CACHE_URI,
    CELERY_TASK_RESULT_EXPIRES=300,
    CELERY_QUEUES=(
        Queue(HOSTNAME + '.dns', Exchange(
            'dnsdriver', type='direct'), routing_key='dnsdriver'),
    )
)


@celery.task(name='firewall.reload_dns')
def t(data):
    with open('/etc/sv/tinydns/root/data', 'w') as f:
        f.write('\n'.join(data))
    process = subprocess.Popen(['make', '-C', '/etc/sv/tinydns/root'],
                               shell=False, stdin=subprocess.PIPE)
    process.communicate('\n'.join(data) + '\n')
